import type { Component, defineComponent } from "vue";

export enum componentUpdateTrigger {
  "Input" = "onBlur",
  "InputNumber" = "onChange",
  "Select" = "onChange",
  "Cascader" = "onChange",
  "CheckGroup" = "onChange",
  "Date" = "onChange",
  "RadioGroup" = "onChange",
  "Rate" = "onChange",
  "Slider" = "onChange",
  "Switch" = "onChange",
  "TimePicker" = "onChange",
  "TimeSelect" = "onChange",
}

export type TableComponentType = keyof typeof componentUpdateTrigger;

const TableComponents = new Map<TableComponentType, Component>();

import ECascader from "./ECascader.vue";
import EInput from "./EInput.vue";
import EInputNumber from "./EInputNumber.vue";
import ESelect from "./ESelect.vue";
import ECheckBoxGroup from "./ECheckBoxGroup.vue";
import EDatePicker from "./EDatePicker.vue";
import ERadioGroup from "./ERadioGroup.vue";
import ERate from "./ERate.vue";
import ESlider from "./ESlider.vue";
import ESwitch from "./ESwitch.vue";
import ETimePicker from "./ETimePicker.vue";
import ETimeSelect from "./ETimeSelect.vue";

TableComponents.set("Cascader", ECascader);
TableComponents.set("Input", EInput);
TableComponents.set("InputNumber", EInputNumber);
TableComponents.set("Select", ESelect);
TableComponents.set("CheckGroup", ECheckBoxGroup);
TableComponents.set("Date", EDatePicker);
TableComponents.set("RadioGroup", ERadioGroup);
TableComponents.set("Rate", ERate);
TableComponents.set("Slider", ESlider);
TableComponents.set("Switch", ESwitch);
TableComponents.set("TimePicker", ETimePicker);
TableComponents.set("TimeSelect", ETimeSelect);

export function getComponents(
  key: TableComponentType
): ReturnType<typeof defineComponent> {
  return TableComponents.get(key);
}
