import type { TableColumnCtx } from "element-plus/lib/components/table/src/table-column/defaults";
import type { TableComponentType } from "../editColumn/components";
import type { editUpdateArguments, slotParams } from "./table";
import type { EditColumnProps, EditComponentProps } from "./table-editItem";

export type { TableColumnCtx };

export type ETableColumnCtx = Partial<TableColumnCtx<any>> & {
  prop?: string;
  type?: "default" | "index" | "selection" | "expand";
  placeholderText?: string;
};

export interface checkRule {
  type: "Regular" | "Function";
  msg?: string;
  regular?: RegExp;
  fn?: nullFunction<boolean | Promise<boolean>>;
}

export interface ETableColumnEditInfo {
  itemClass?: string;
  canEdit: boolean;
  alwaysShowEdit?: boolean;
  placeValue?: string;
  editType?: TableComponentType | ((p: slotParams) => TableComponentType);
  editItemProps?: Recordable;
  editItemEvent?: Recordable<nullFunction>;
  editComponentAttrs?: {
    // 组件 独特内部属性
    options?: any[]; // 选项
    contrast?: {
      // 字段 映射
      label: string;
      value: string;
      [key: string]: any;
    };
  };
  editCheckRules?: checkRule[]; // 数据更新格式校验
  editCheck?: nullFunction<boolean>; // 是否显示 修改检测
  editItemScopedSlots?: nullFunction; // 编辑组件内 插槽
  originalValueFormate?: (p: EditComponentProps) => any; // 原始数据格式化
  updateDataFormate?: (obj: Partial<editUpdateArguments>) => any; // 修改校验 格式化数据
  supplementaryData?: (obj: Partial<editUpdateArguments>) => any; // 更新数据传入额外参数
  defaultValueSlot?: (props: EditColumnProps) => nullFunction; // 默认数据格式化
  extraSlots?: (props: EditColumnProps) => {
    first?: nullFunction;
    last?: nullFunction;
  }; // 额外插槽
}

export interface ETableColumnInfo {
  columnAttribute: ETableColumnCtx;
  columnEvent?: Recordable;
  independentId?: string;
  scopedSlots?: nullFunction | undefined;
  columnChildren?: ETableColumnInfo[];
  editInfo?: ETableColumnEditInfo;
}

export type ETableComplementInfo = Partial<ETableColumnInfo>;

export type ETableColumns = ETableColumnInfo[];

export const defaultColumnBasicAttrs: ETableColumnCtx = {
  type: "default",
  align: "center",
  formatter: (r, c, v) => {
    return v || "--";
  },
};
